==> sceptre-00.317.tar.gz: x1/compck.f <==
CSECT   COMPCK                          71.042  11.43.38
 
       SUBROUTINE COMPCK (TERM,CODE,MODE,OUT)
 
CWRN: 94.129 - error message extended for illegal E/C sets

C      PROGRAM TO CHECK OR TURN-ON THE COMPUTE FLAG OF A VARIABLE.
C      J. SENTS   5/6/66
C
C      TERM   - IS THE VARIABLE NAME FOR WHICH THE COMPUTE FLAG WILL BE
C                     CHECKED OR TURNED-ON
C      CODE   - IS THE TYPE CODE OF THE VARIABLE TERM
C      MODE   - INDICATES EITHER CHECK (MODE=0) OR TURN-ON (MODE=1) MODE
C      OUT    - IS THE COMPUTE FLAG STATUS. OFF(OUT=0), ON(OUT=1)
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z),INTEGER (I-N)
 
	include 'tapes.inc'
	include 'dfpram.inc'
         CHARACTER*8  DPTABL
         CHARACTER*8  DPNAME(jqqram)
         CHARACTER*8  DCFTB(jqqram)
         EQUIVALENCE (DPNAME,DPTABL(1,1)),(DCFTB,DPTABL(1,4))

      COMMON /ELDATA/ EL,NELMTS,LELMTS,ELMTAB(300,7)
         CHARACTER*8  ELMTAB
         CHARACTER*8  ELNAME(300)
         CHARACTER*8  CFLGTB(300)
         EQUIVALENCE (ELNAME,ELMTAB(1,1)),(CFLGTB,ELMTAB(1,6))
      COMMON /MUTUAL/ AU,NMUTL,LMUTL,MUTLTB(50,6)
         CHARACTER*8  MUTLTB
         CHARACTER*8  MUTNAM(50)
         CHARACTER*8  MCF(50)
         EQUIVALENCE (MUTNAM,MUTLTB(1,2)),(MCF,MUTLTB(1,6))
      INTEGER         CODE,OUT
      CHARACTER*8     VNAME, TERM

C  old location pointer LOC mapped to character position loc=7-LOC
C  DATA ONN /ZF0000,ZF000000,ZF00000000,ZF0000000000,ZF000000000000/
C  DATA OFF /ZFF0000,ZFF000000,ZFF00000000,ZFF0000000000,ZFF000000000000
 
       VNAME=TERM
       OUT=1
       LOC=6
       GO TO (300,150,300,300,100,20,20,20,20,30,100,200,40,50,60,
     .        300,300,90,90,80),CODE
 
C      IR,IL,IC,VR,VL,VC,GR,SC,HL,DC,DL
 
   20  LOC=11-CODE
       GO TO 90
 
C      DE,DJ
 
   30  LOC=2
       GO TO 90
 
C      IE
 
   40  LOC=5
       GO TO 90
 
C      VJ
 
   50  LOC=4
       GO TO 90
 
C      DP
 
   60  LOC=2
       VNAME=TERM(2:6)
       GO TO 150
 
C      GJ
 
   80  LOC=3
       GO TO 100

   90  VNAME=TERM(2:6)
 
C      LOOK-UP ELEMENT NAME IN ELEMENTS TABLE
 
  100  DO 110 N=1,NELMTS
       IF (VNAME .EQ. ELNAME(N)) then
          IF (MODE .NE. 0) then
C            TURN COMPUTE FLAG ON
             ibyte=ichar(cflgtb(n)(loc:loc))
             cflgtb(n)(loc:loc)=char(ior(ibyte,15))
cwrn:        print 77,n,loc,ibyte,term,code
             GO TO 300
           else
C            GET COMPUTE FLAG
             ibyte=ichar(cflgtb(n)(loc:loc))
             GO TO 230
          end if
       end if 
  110  continue
   77  format (' COMPCK: set cflgtb(',i3,') at loc ',i1,' to ',
     *        i3,' + X''F'' for term "',a,'", code=',i2)
 
  115  WRITE (iqqout,120) TERM
  120  FORMAT('0THE VARIABLE ''',A6,''' CANNOT BE FOUND IN EITHER ',
     .        'THE LIST OF CIRCUIT ELEMENTS OR DEFINED PARAMETERS ',
     .        'BY ''COMPCK''.'/' Check also for illegal E/C loop.')
       STOP 'COMPCK: variable not found, run aborted'

 
C      LOOK-UP DEFINED PARAMETER NAME
 
  150  DO 160 N=1,NDP
       IF (VNAME .EQ. DPNAME(N)) then
          IF (MODE .NE. 0) then
             ibyte=ichar(dcftb(n)(loc:loc))
             dcftb(n)(loc:loc)=char(ior(ibyte,15))
cwrn:        print 77,n,loc,ibyte,term,code
             GO TO 300
           else
             ibyte=ichar(dcftb(n)(loc:loc))
             GO TO 230
          end if
       end if
  160  continue
       GO TO 115
 
C      LOOK-UP VARIABLE NAME IN MUTUAL TABLE
 
  200  DO 210 N=1,NMUTL
       IF (VNAME .EQ. MUTNAM(N)) then
          IF (MODE .NE. 0) then
             ibyte=ichar(mcf(n)(loc:loc))
             mcf(n)(loc:loc)=char(ior(ibyte,15))
cwrn:        print 77,n,loc,ibyte,term,code
             go to 300
           else
             ibyte=ichar(mcf(n)(loc:loc))
             go to 230
          end if
       end if
  210  continue
       GO TO 115

  230  IF (ibyte .EQ. 0) OUT=0
  300  RETURN
 
       END

==> sceptre-2012.061.tar.gz: x1/compck.f <==
CSECT   COMPCK                          71.042  11.43.38
 
       SUBROUTINE COMPCK (TERM,CODE,MODE,OUT)
 
CWRN: 94.129 - error message extended for illegal E/C sets

C      PROGRAM TO CHECK OR TURN-ON THE COMPUTE FLAG OF A VARIABLE.
C      J. SENTS   5/6/66
C
C      TERM   - IS THE VARIABLE NAME FOR WHICH THE COMPUTE FLAG WILL BE
C                     CHECKED OR TURNED-ON
C      CODE   - IS THE TYPE CODE OF THE VARIABLE TERM
C      MODE   - INDICATES EITHER CHECK (MODE=0) OR TURN-ON (MODE=1) MODE
C      OUT    - IS THE COMPUTE FLAG STATUS. OFF(OUT=0), ON(OUT=1)
 
      IMPLICIT DOUBLE PRECISION (A-H,O-Z),INTEGER (I-N)
 
      include 'tapes.inc'
      include 'dfpram.inc'
         CHARACTER*8  DPTABL
         CHARACTER*8  DPNAME(jqqram)
         CHARACTER*8  DCFTB(jqqram)
         EQUIVALENCE (DPNAME,DPTABL(1,1)),(DCFTB,DPTABL(1,4))

      COMMON /ELDATA/ EL,NELMTS,LELMTS,ELMTAB(300,7)
         CHARACTER*8  ELMTAB
         CHARACTER*8  ELNAME(300)
         CHARACTER*8  CFLGTB(300)
         EQUIVALENCE (ELNAME,ELMTAB(1,1)),(CFLGTB,ELMTAB(1,6))
      COMMON /MUTUAL/ AU,NMUTL,LMUTL,MUTLTB(50,6)
         CHARACTER*8  MUTLTB
         CHARACTER*8  MUTNAM(50)
         CHARACTER*8  MCF(50)
         EQUIVALENCE (MUTNAM,MUTLTB(1,2)),(MCF,MUTLTB(1,6))
      INTEGER         CODE,OUT
      CHARACTER*8     VNAME, TERM

C  old location pointer LOC mapped to character position loc=7-LOC
C  DATA ONN /ZF0000,ZF000000,ZF00000000,ZF0000000000,ZF000000000000/
C  DATA OFF /ZFF0000,ZFF000000,ZFF00000000,ZFF0000000000,ZFF000000000000
 
       VNAME=TERM
       OUT=1
       LOC=6
       GO TO (300,150,300,300,100,20,20,20,20,30,100,200,40,50,60,
     .        300,300,90,90,80),CODE
 
C      IR,IL,IC,VR,VL,VC,GR,SC,HL,DC,DL
 
   20  LOC=11-CODE
       GO TO 90
 
C      DE,DJ
 
   30  LOC=2
       GO TO 90
 
C      IE
 
   40  LOC=5
       GO TO 90
 
C      VJ
 
   50  LOC=4
       GO TO 90
 
C      DP
 
   60  LOC=2
       VNAME=TERM(2:6)
       GO TO 150
 
C      GJ
 
   80  LOC=3
       GO TO 100

   90  VNAME=TERM(2:6)
 
C      LOOK-UP ELEMENT NAME IN ELEMENTS TABLE
 
  100  DO 110 N=1,NELMTS
       IF (VNAME .EQ. ELNAME(N)) then
          IF (MODE .NE. 0) then
C            TURN COMPUTE FLAG ON
             ibyte=ichar(cflgtb(n)(loc:loc))
             cflgtb(n)(loc:loc)=char(ior(ibyte,15))
cwrn:        print 77,n,loc,ibyte,term,code
             GO TO 300
           else
C            GET COMPUTE FLAG
             ibyte=ichar(cflgtb(n)(loc:loc))
             GO TO 230
          end if
       end if 
  110  continue
c   77  format (' COMPCK: set cflgtb(',i3,') at loc ',i1,' to ',
c     *        i3,' + X''F'' for term "',a,'", code=',i2)
 
  115  WRITE (iqqout,120) TERM
  120  FORMAT('0THE VARIABLE ''',A6,''' CANNOT BE FOUND IN EITHER ',
     .        'THE LIST OF CIRCUIT ELEMENTS OR DEFINED PARAMETERS ',
     .        'BY ''COMPCK''.'/' Check also for illegal E/C loop.')
       STOP 'COMPCK: variable not found, run aborted'

 
C      LOOK-UP DEFINED PARAMETER NAME
 
  150  DO 160 N=1,NDP
       IF (VNAME .EQ. DPNAME(N)) then
          IF (MODE .NE. 0) then
             ibyte=ichar(dcftb(n)(loc:loc))
             dcftb(n)(loc:loc)=char(ior(ibyte,15))
cwrn:        print 77,n,loc,ibyte,term,code
             GO TO 300
           else
             ibyte=ichar(dcftb(n)(loc:loc))
             GO TO 230
          end if
       end if
  160  continue
       GO TO 115
 
C      LOOK-UP VARIABLE NAME IN MUTUAL TABLE
 
  200  DO 210 N=1,NMUTL
       IF (VNAME .EQ. MUTNAM(N)) then
          IF (MODE .NE. 0) then
             ibyte=ichar(mcf(n)(loc:loc))
             mcf(n)(loc:loc)=char(ior(ibyte,15))
cwrn:        print 77,n,loc,ibyte,term,code
             go to 300
           else
             ibyte=ichar(mcf(n)(loc:loc))
             go to 230
          end if
       end if
  210  continue
       GO TO 115

  230  IF (ibyte .EQ. 0) OUT=0
  300  RETURN
 
       END
